@@ -3,6 +3,7 @@ from writer.blocks.apitrigger import APITrigger
 from writer.blocks.calleventhandler import CallEventHandler
 from writer.blocks.changepage import ChangePage
 from writer.blocks.code import CodeBlock
+from writer.blocks.crontrigger import CronTrigger
 from writer.blocks.foreach import ForEach
 from writer.blocks.httprequest import HTTPRequest
 from writer.blocks.logmessage import LogMessage
@@ -20,12 +21,14 @@ from writer.blocks.writerclassification import WriterClassification
 from writer.blocks.writercompletion import WriterCompletion
 from writer.blocks.writerfileapi import WriterUploadFile
 from writer.blocks.writerinitchat import WriterInitChat
+from writer.blocks.writerkeyvaluestorage import WriterKeyValueStorage
 from writer.blocks.writernocodeapp import WriterNoCodeApp
 from writer.blocks.writerparsepdf import WriterParsePDFByFileID
 from writer.blocks.writerstructuredoutput import WriterStructuredOutput
 from writer.blocks.writertoolcalling import WriterToolCalling
 from writer.blocks.writervision import WriterVision
- 
+from writer.blocks.writerwebsearch import WriterWebSearch
+
 SetState.register("blueprints_setstate")
 WriterClassification.register("blueprints_writerclassification")
 WriterCompletion.register("blueprints_writercompletion")
@@ -45,6 +48,7 @@ WriterInitChat.register("blueprints_writerinitchat")
 WriterAddToKG.register("blueprints_writeraddtokg")
 UIEventTrigger.register("blueprints_uieventtrigger")
 APITrigger.register("blueprints_apitrigger")
+CronTrigger.register("blueprints_crontrigger")
 CodeBlock.register("blueprints_code")
 ChangePage.register("blueprints_changepage")
 WriterStructuredOutput.register("blueprints_writerstructuredoutput")
@@ -53,3 +57,5 @@ WriterAskGraphQuestion.register("blueprints_writeraskgraphquestion")
 WriterParsePDFByFileID.register("blueprints_writerparsepdf")
 WriterUploadFile.register("blueprints_writeruploadfile")
 WriterVision.register("blueprints_writervision")
+WriterWebSearch.register("blueprints_writerwebsearch")
+WriterKeyValueStorage.register("blueprints_writerkeyvaluestorage")
