@@ -221,6 +221,24 @@ def get_asgi_app(
 
     @app.get("/api/health")
     async def health():
+        app_runner = app.state.app_runner
+        
+        # Check user app process
+        if app_runner.app_process is None or not app_runner.app_process.is_alive():
+            return JSONResponse(
+                status_code=503,
+                content={"status": "error", "message": "User app process is not running"}
+            )
+        
+        # Check project saver process (only in edit mode)
+        if app_runner.mode == "edit":
+            project_saver = app_runner.wf_project_context.write_files_async_process
+            if project_saver is None or not project_saver.is_alive():
+                return JSONResponse(
+                    status_code=503,
+                    content={"status": "error", "message": "Project saver process is not running"}
+                )
+        
         return {"status": "ok"}
 
     @app.get("/api/export")
@@ -361,8 +379,30 @@ def get_asgi_app(
 
         return JSONResponse(content=blueprints)
 
+    @app.get("/private/api/cron-triggers")
+    async def get_cron_triggers(request: Request):
+        """
+        Returns a list of Cron Trigger blocks.
+        """
+        if not app_runner.bmc_components:
+            return JSONResponse(content=[], status_code=200)
+
+        cron_triggers = [
+            {
+                "id": comp.get("id"),
+                "blueprint_id": comp.get("parentId"),
+                "name": comp.get("name") or comp.get("content", {}).get("name"),
+                "cron_expression": comp.get("content", {}).get("cronExpression", ""),
+                "timezone": comp.get("content", {}).get("timezone", "UTC"),
+            }
+            for comp in app_runner.bmc_components.values()
+            if comp.get("type") == "blueprints_crontrigger"
+        ]
+
+        return JSONResponse(content=cron_triggers, status_code=200)
+
     @app.post("/private/api/blueprint/{blueprint_id}")
-    async def create_blueprint_job(blueprint_id: str, request: Request, response: Response):
+    async def create_blueprint_job(blueprint_id: str, request: Request, response: Response, branch_id: Optional[str] = None):
         # Keep-alive interval for SSE streaming
         KEEPALIVE_INTERVAL = 15
         payload = await _get_payload_as_json(request)
@@ -443,29 +483,50 @@ def get_asgi_app(
                     }))
                     return
 
-                if not has_api_trigger(app_runner, blueprint_id):
+                if not branch_id and not has_api_trigger(app_runner, blueprint_id):
                     await queue.put(await format_event("error", {
                         "msg": f"Blueprint '{blueprint_id}' lacks an API trigger.",
                         "finished_at": int(time.time())
                     }))
                     return
 
-                await queue.put(await format_event("status", {"status": "executing", "msg": f"Executing blueprint: {blueprint_id}..."}))
+                if branch_id:
+                    block = app_runner.bmc_components.get(branch_id)
+                    if not block:
+                        await queue.put(await format_event("error", {
+                            "msg": f"Block '{branch_id}' was not found.",
+                            "finished_at": int(time.time())
+                        }))
+                        return
 
-                # Kick off actual blueprint execution as background task
-                task = asyncio.create_task(
-                    app_runner.handle_event(
-                        session_id,
-                        WriterEvent(
-                            type="wf-run-blueprint-via-api",
-                            isSafe=True,
-                            handler="run_blueprint_via_api",
-                            payload={"blueprint_id": blueprint_id, **(payload or {})},
+                await queue.put(await format_event("status", {"status": "executing", "msg": (f"Executing branch: {branch_id}..." if branch_id else f"Executing blueprint: {blueprint_id}...")}))
+
+                if branch_id:
+                    task = asyncio.create_task(
+                        app_runner.handle_event(
+                            session_id,
+                            WriterEvent(
+                                type="wf-run-blueprint-branch",
+                                isSafe=True,
+                                handler="run_blueprint_branch",
+                                payload={"branch_id": branch_id, **(payload or {})},
+                            )
+                        )
+                    )
+                else:
+                    task = asyncio.create_task(
+                        app_runner.handle_event(
+                            session_id,
+                            WriterEvent(
+                                type="wf-run-blueprint-via-api",
+                                isSafe=True,
+                                handler="run_blueprint_via_api",
+                                payload={"blueprint_id": blueprint_id, **(payload or {})},
+                            )
                         )
                     )
-                )
 
-                await queue.put(await format_event("status", {"status": "running", "msg": "Blueprint is running. Awaiting output..."}))
+                await queue.put(await format_event("status", {"status": "running", "msg": ("Branch is running. Awaiting output..." if branch_id else "Blueprint is running. Awaiting output...")}))
 
                 # Await blueprint execution with timeout protection
                 apsr = await asyncio.wait_for(task, timeout=BLUEPRINT_API_EXECUTION_TIMEOUT_SECONDS)
@@ -770,6 +831,7 @@ def get_asgi_app(
         Handles outgoing communications to the client (announcements).
         """
 
+        WEBSOCKET_CODE_UPDATE_CODE = 4001
         session_queue: asyncio.Queue = asyncio.Queue()
         app_runner.announcement_queues[session_id] = session_queue
 
@@ -782,6 +844,7 @@ def get_asgi_app(
                 if websocket.application_state == WebSocketState.CONNECTED:
                     await websocket.send_json(announcement.dict())
                 if announcement_data.get("type") == "codeUpdate":
+                    await websocket.close(WEBSOCKET_CODE_UPDATE_CODE, "Code update.")
                     return
         except WebSocketDisconnect:
             pass
